Struct google_docs1::api::DeleteHeaderRequest
source · pub struct DeleteHeaderRequest {
pub header_id: Option<String>,
}Expand description
Deletes a Header from the document.
This type is not used in any activity, and only used as part of another schema.
Fields
header_id: Option<String>The id of the header to delete. If this header is defined on DocumentStyle, the reference to this header is removed, resulting in no header of that type for the first section of the document. If this header is defined on a SectionStyle, the reference to this header is removed and the header of that type is now continued from the previous section.