Struct google_docs1::api::UpdateDocumentStyleRequest [−][src]
Updates the DocumentStyle.
This type is not used in any activity, and only used as part of another schema.
Fields
document_style: Option<DocumentStyle>The styles to set on the document. Certain document style changes may cause other changes in order to mirror the behavior of the Docs editor. See the documentation of DocumentStyle for more information.
fields: Option<String>The fields that should be updated. At least one field must be specified. The root document_style is implied and should not be specified. A single "*" can be used as short-hand for listing every field. For example to update the background, set fields to "background".